@@ -4,38 +4,24 @@
  *
  * Copyright (C) 2010,2011,2015 Olaf Bergmann <bergmann@tzi.org>
  *
- * SPDX-License-Identifier: BSD-2-Clause
- *
  * This file is part of the CoAP library libcoap. Please see README for terms of
  * use.
  */
 
-/*
- * examples/coap_list.[ch] are DEPRECATED.  You should be using
- * struct coap_optlist_t instead with the following functions which are a part
- * of libcoap.
- *
- * coap_new_optlist()
- * coap_insert_optlist()
- * coap_delete_optlist()
- * coap_add_optlist_pdu()
- *
- * See 'man coap_pdu_setup' for further information.
- *
- * examples/coap_list.[ch] files will be removed in a future release
- * They are left here to support building backward compatability of old versions
- * of coap-client
- */
+/* #include "coap_config.h" */
 
 #include <stdio.h>
 #include <string.h>
 
-#include <coap3/coap.h>
+#include "debug.h"
+#include "mem.h"
+#include "coap_list.h"
+
 
 int
 coap_insert(coap_list_t **head, coap_list_t *node) {
   if (!node) {
-    coap_log_warn("cannot create option Proxy-Uri\n");
+    coap_log(LOG_WARNING, "cannot create option Proxy-Uri\n");
   } else {
     /* must append at the list end to avoid re-ordering of
      * options during sort */
@@ -64,3 +50,4 @@ coap_delete_list(coap_list_t *queue) {
     coap_delete(elt);
   }
 }
+
